"""
web2ldap plugin classes for attributes defined in RFC2307

$Id: posixaccount.py,v 1.3 2005/06/01 17:50:43 michael Exp $
"""

import pyweblib.forms

from w2lapp.schema.syntaxes import SelectList,IntegerRange,DaysSinceEpoch,syntax_registry


class UidNumber(IntegerRange):
  oid = 'UidNumber-oid'
  desc = 'Numerical user ID for Posix systems'
  minValue = 0
  maxValue = 4294967295L


class Shell(SelectList):
  oid = 'Shell-oid'
  desc = 'Shell for user of Posix systems'

  attr_value_dict = {
    '':'',
    '/bin/bash':'Bourne-Again SHell',
    '/bin/tcsh':'tcsh',
    '/bin/ksh':'Korn shell',
    '/bin/passwd':'Password change',
    '/bin/false':'false',
  }


# Register all syntax classes in this module
for name in dir():
  syntax_registry.registerSyntaxClass(eval(name))

syntax_registry.registerAttrType(
  UidNumber.oid,[
    '1.3.6.1.1.1.1.0', # uidNumber
  ]
)

syntax_registry.registerAttrType(
  Shell.oid,[
    '1.3.6.1.1.1.1.4', # loginShell
  ]
)


syntax_registry.registerAttrType(
  DaysSinceEpoch.oid,[
    '1.3.6.1.1.1.1.10', # shadowExpire
    '1.3.6.1.1.1.1.5', # shadowLastChange
  ]
)
